<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:fn="http://textgrid.info/namespaces/functions/p2"
    xmlns="http://www.w3.org/1999/xhtml"
    exclude-result-prefixes="fn"
    >
    <xsl:output method="xhtml" indent="yes" doctype-public="html"/>
    <xsl:strip-space elements="*"/>
    
    <xsl:template match="/">
        <html xmlns="http://www.w3.org/1999/xhtml">
            <xsl:apply-templates/>
        </html>
    </xsl:template>
    
    <xsl:template match="repository[units]">
        <xsl:call-template name="head"/>
        <body>
            <div id="container">
                <div id="bg-decoration"/>
                <!--nav>
                    <ul>
                    <li><a href="#container">Info</a></li>
                    <li><a href="#features">Features</a></li>
                    <li><a href="#plugins">Plugins</a></li>
                    </ul>
                    </nav-->
                <div id="main">
                    
                    <h1>
                        <xsl:value-of select="@name"/>
                    </h1>
                    <xsl:call-template name="explanation"/>
                    
                    <hr/>
                    <h2>Repository Contents</h2>
                    <p>For your information, here's the contents of this repository:</p>
                    <section xml:id="features">
                    <h3>Features</h3>
                        <xsl:apply-templates
                            select="//provided[@namespace='org.eclipse.update.feature']">
                            <!--xsl:sort select="@name"/-->
                        </xsl:apply-templates>
                    </section>
                     <hr/>
                    <section xml:id="plugins">
                     <h3>Plugins</h3>
                        <xsl:apply-templates select="//provided[@namespace='osgi.bundle']">
                            <xsl:sort select="@name"/>
                        </xsl:apply-templates>
                    </section>
                </div>
            </div>

        </body>
    </xsl:template>
    <xsl:template name="explanation">
        <article class="explanation">
            <h3>TextGridLab Update Site</h3>
            <p>This is a <em>p2 repository</em>, it contains tools that can be installed
                into the TextGridLab using its internal update mechanism. To do so,
                either use the marketplace (Help / Marketplace) if the tool is present
                there, or directly use the installation tool: </p>
            <ol>
                <li>Help / Install new software ...</li>
                <li>Enter this site's URL into the <em>Work with</em> field and press return</li>
                <li>Select the tools you would like to install from the tree below</li>
                <li>Finish the dialog, accept licenses etc.</li>
                <li>Quit.</li>
            </ol>
        </article>
    </xsl:template>
    <xsl:template name="head">
        <head>
            <link rel="stylesheet" type="text/css" href="http://textgridrep.de/css/style.css"/>
            <style type="text/css">
                h1, h2, h3 { margin: 2ex 0 1ex 0; }
                ol li { list-style-type: decimal; }
                .version { color: #99f; }
                .name { float: right; color: #666; }
                .description { whitespace: pre-wrap; }
                .iu { padding: 5px 0; }
                .iu:hover { background: #fcfcfc; }
            </style>
            <title>
                <xsl:value-of select="@name"/>
            </title>
        </head>
    </xsl:template>

    <xsl:template match="provided">
        <section class="iu">
            <h4>
                <xsl:if test="fn:property(., 'org.eclipse.equinox.p2.name') and fn:property(., 'org.eclipse.equinox.p2.name') != @name">                    
                    <span class="name"><xsl:text> </xsl:text><xsl:value-of select="fn:property(., 'org.eclipse.equinox.p2.name')"/></span>
                </xsl:if>
                <span class="id">
                    <xsl:value-of select="@name"/>
                </span>
                <xsl:text> </xsl:text>
                <span class="version">
                    <xsl:value-of select="@version"/>
                </span>
            </h4>
            
            <xsl:if test="fn:property(., 'org.eclipse.equinox.p2.description')">
                <p class="description">
                    <xsl:value-of select="fn:property(., 'org.eclipse.equinox.p2.description')"/>
                </p>
            </xsl:if>
                        
        </section>
    </xsl:template>
    
    
    <xsl:template match="repository[children]">
        <xsl:call-template name="head"/>
        <body>
            <div id="container">
                <div id="bg-decoration"/>
                <!--nav>
                    <ul>
                    <li><a href="#container">Info</a></li>
                    <li><a href="#features">Features</a></li>
                    <li><a href="#plugins">Plugins</a></li>
                    </ul>
                    </nav-->
                <div id="main">
                    
                    <h1>
                        <xsl:value-of select="@name"/>
                    </h1>
                    <xsl:call-template name="explanation"/>
                    
                    <hr/>
                    <h2>Child Repositories</h2>
                    <p>This is a <em>composite repository</em>. The actual contents is in this
                    repository's children (or their children, respectively). Below is a list of
                    child repositories:</p>
                    
                    <ol>
                        <xsl:apply-templates select=".//child"></xsl:apply-templates>
                    </ol>
                </div>
            </div>
        </body>
    </xsl:template>
    
    <xsl:template match="child">
        <li><a href="{@location}"><xsl:value-of select="@location"/></a></li>
    </xsl:template>
    
    
    <xsl:function name="fn:property">
        <xsl:param name="context"/>
        <xsl:param name="name"/>
        <xsl:variable name="candidate" select="$context/ancestor-or-self::unit[1]/properties/property[@name=$name]/@value"/>
        <xsl:if test="$candidate">
            <xsl:choose>
                <xsl:when test="starts-with($candidate, '%')">
                    <xsl:value-of select="$context/ancestor-or-self::unit[1]/properties/property[ends-with(@name,
                        concat('.', substring($candidate, 2)))][1]/@value"></xsl:value-of>
                </xsl:when>
                <xsl:otherwise>                    
                    <xsl:value-of select="$candidate"/>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:if>
    </xsl:function>   

</xsl:stylesheet>
